==> mx-samba-config_22.1.tar.xz: mx-samba-config-22.1/translations/mx-samba-config_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>EditShare</name>
    <message>
        <location filename="editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="56"/>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="editshare.cpp" line="49"/>
        <source>Select directory to share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Paylaşılanlar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="50"/>
        <location filename="mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="63"/>
        <location filename="mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>İzinler</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>Kullanıcılar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Samba kullanıcısı bulunamadı&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Kullanıcılar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="mainwindow.cpp" line="273"/>
        <location filename="mainwindow.cpp" line="299"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="226"/>
        <location filename="mainwindow.cpp" line="252"/>
        <location filename="mainwindow.cpp" line="308"/>
        <source>Star&amp;t Samba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="285"/>
        <location filename="mainwindow.cpp" line="250"/>
        <source>Samba is running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.ui" line="334"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="366"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="369"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="376"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="414"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="79"/>
        <location filename="mainwindow.cpp" line="83"/>
        <location filename="mainwindow.cpp" line="106"/>
        <location filename="mainwindow.cpp" line="119"/>
        <location filename="mainwindow.cpp" line="176"/>
        <location filename="mainwindow.cpp" line="238"/>
        <location filename="mainwindow.cpp" line="256"/>
        <location filename="mainwindow.cpp" line="345"/>
        <location filename="mainwindow.cpp" line="372"/>
        <location filename="mainwindow.cpp" line="376"/>
        <location filename="mainwindow.cpp" line="381"/>
        <location filename="mainwindow.cpp" line="386"/>
        <location filename="mainwindow.cpp" line="416"/>
        <location filename="mainwindow.cpp" line="422"/>
        <location filename="mainwindow.cpp" line="436"/>
        <location filename="mainwindow.cpp" line="446"/>
        <location filename="mainwindow.cpp" line="477"/>
        <location filename="mainwindow.cpp" line="488"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="79"/>
        <source>Error, could not add share. Empty share name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="83"/>
        <source>Path: %1 doesn&apos;t exist.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <location filename="mainwindow.cpp" line="135"/>
        <source>Everyone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="104"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="106"/>
        <source>Could not add share. Error message:

%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <source>Error listing users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="144"/>
        <source>&amp;Deny</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="150"/>
        <source>&amp;Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="156"/>
        <source>&amp;Full Access</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="176"/>
        <source>Error listing shares</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="239"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Sto&amp;p Samba</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="253"/>
        <source>Samba is not running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>Samba not installed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="270"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="321"/>
        <source>About %1</source>
        <translation>%1 Hakkında </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="321"/>
        <source>MX Samba Config</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="323"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="324"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="326"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>%1 License</source>
        <translation>%1 Ruhsat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="335"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="345"/>
        <source>Cannot delete user: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="353"/>
        <source>Enter the username and password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <location filename="mainwindow.cpp" line="405"/>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <location filename="mainwindow.cpp" line="406"/>
        <source>Confirm password:</source>
        <translation>Parolayı onayla:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="372"/>
        <source>Empty username, please enter a name.</source>
        <translation>Kullanıcı adı boş, lütfen bir ad girin.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="381"/>
        <location filename="mainwindow.cpp" line="416"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="386"/>
        <source>Could not add user.</source>
        <translation>Kullanıcı eklenemedi.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="399"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="422"/>
        <source>Could not change password.</source>
        <translation>Parola değiştirilemedi.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="436"/>
        <source>Cannot delete share: </source>
        <translation>Paylaşım silinemiyor:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="447"/>
        <location filename="mainwindow.cpp" line="489"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="477"/>
        <source>Error: trying to process permissions: </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="58"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="about.cpp" line="59"/>
        <location filename="about.cpp" line="69"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="about.cpp" line="60"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="about.cpp" line="81"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="main.cpp" line="61"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>

==> mx-samba-config_22.8.tar.xz: mx-samba-config-22.8/translations/mx-samba-config_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>EditShare</name>
    <message>
        <location filename="editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="56"/>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation>&amp;Misafir TAMAM</translation>
    </message>
    <message>
        <location filename="editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation>Geçerli kullanıcılar için erişim hakları</translation>
    </message>
    <message>
        <location filename="editshare.cpp" line="49"/>
        <source>Select directory to share</source>
        <translation>Paylaşılacak dizini seçin</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation>&amp;Paylaşımlar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Paylaşılanlar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Samba kullanıcı paylaşımı bulunamadı&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="50"/>
        <location filename="mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="63"/>
        <location filename="mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation>%Ekle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>İzinler</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation>Misafir TAMAM</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>Kullanıcılar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Samba kullanıcısı bulunamadı&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Kullanıcılar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="mainwindow.cpp" line="273"/>
        <location filename="mainwindow.cpp" line="299"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation>Samba&apos;nın Otomatik Başlamasını Etki&amp;nleştir</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="226"/>
        <location filename="mainwindow.cpp" line="252"/>
        <location filename="mainwindow.cpp" line="308"/>
        <source>Star&amp;t Samba</source>
        <translation>Samba&apos;yı Başla&amp;t</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation>Samba otomatik başlatma servisi devre dışı</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="285"/>
        <location filename="mainwindow.cpp" line="250"/>
        <source>Samba is running</source>
        <translation>Samba çalışıyor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation>&amp;Hakkında...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="334"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="366"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="369"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="376"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="414"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="79"/>
        <location filename="mainwindow.cpp" line="83"/>
        <location filename="mainwindow.cpp" line="106"/>
        <location filename="mainwindow.cpp" line="119"/>
        <location filename="mainwindow.cpp" line="176"/>
        <location filename="mainwindow.cpp" line="238"/>
        <location filename="mainwindow.cpp" line="256"/>
        <location filename="mainwindow.cpp" line="345"/>
        <location filename="mainwindow.cpp" line="372"/>
        <location filename="mainwindow.cpp" line="376"/>
        <location filename="mainwindow.cpp" line="381"/>
        <location filename="mainwindow.cpp" line="386"/>
        <location filename="mainwindow.cpp" line="416"/>
        <location filename="mainwindow.cpp" line="422"/>
        <location filename="mainwindow.cpp" line="436"/>
        <location filename="mainwindow.cpp" line="446"/>
        <location filename="mainwindow.cpp" line="477"/>
        <location filename="mainwindow.cpp" line="488"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="79"/>
        <source>Error, could not add share. Empty share name</source>
        <translation>Hata, paylaşım eklenemedi. Paylaşım adı boş</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="83"/>
        <source>Path: %1 doesn&apos;t exist.</source>
        <translation>Yol: %1 mevcut değil.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <location filename="mainwindow.cpp" line="135"/>
        <source>Everyone</source>
        <translation>Herkes</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="104"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="106"/>
        <source>Could not add share. Error message:

%1</source>
        <translation>Paylaşım eklenemedi. Hata mesajı:

%1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <source>Error listing users</source>
        <translation>Kullanıcıları listeleme hatası</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="144"/>
        <source>&amp;Deny</source>
        <translation>Re&amp;ddet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="150"/>
        <source>&amp;Read Only</source>
        <translation>&amp;Sadece oku</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="156"/>
        <source>&amp;Full Access</source>
        <translation>&amp;Tam erişim</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="176"/>
        <source>Error listing shares</source>
        <translation>Paylaşım listeleme hatası</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="239"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation>Kullanıcı adınız &apos;sambashare&apos; grubuna ait değildir, uygulamayı yeni yüklediyseniz, önce sistemi yeniden başlatmanız gerekebilir.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Sto&amp;p Samba</source>
        <translation>Samba&apos;yı &amp;durdur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="253"/>
        <source>Samba is not running</source>
        <translation>Samba çalışmıyor</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>Samba not installed</source>
        <translation>Samba yüklü değil</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="270"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation>&amp;Otomatik Samba Başlatmayı Devre Dışı Bırak</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="321"/>
        <source>About %1</source>
        <translation>%1 Hakkında </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="321"/>
        <source>MX Samba Config</source>
        <translation>MX Samba Yapılandırması</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="323"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="324"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation>Samba paylaşımlarını ve kullanıcılarını yapılandırma programı.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="326"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>%1 License</source>
        <translation>%1 Ruhsat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="335"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="345"/>
        <source>Cannot delete user: </source>
        <translation>Kullanıcı silinemiyor:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="353"/>
        <source>Enter the username and password:</source>
        <translation>Kullanıcı adını ve şifreyi girin:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <location filename="mainwindow.cpp" line="405"/>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <location filename="mainwindow.cpp" line="406"/>
        <source>Confirm password:</source>
        <translation>Parolayı onayla:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="372"/>
        <source>Empty username, please enter a name.</source>
        <translation>Kullanıcı adı boş, lütfen bir ad girin.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation>Sistemde eşleşen linux kullanıcısı bulunamadı, geçerli bir kullanıcı adı girdiğinizden emin olun.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="381"/>
        <location filename="mainwindow.cpp" line="416"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation>Şifreler eşleşmiyor, lütfen tekrar girin.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="386"/>
        <source>Could not add user.</source>
        <translation>Kullanıcı eklenemedi.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="399"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation>&apos;%1&apos; şifresini değiştirin</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="422"/>
        <source>Could not change password.</source>
        <translation>Parola değiştirilemedi.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="436"/>
        <source>Cannot delete share: </source>
        <translation>Paylaşım silinemiyor:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="447"/>
        <location filename="mainwindow.cpp" line="489"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation>Samba hizmeti çalışmıyor. Paylaşımları eklemeden veya düzenlemeden önce lütfen Samba&apos;yı başlatın</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="477"/>
        <source>Error: trying to process permissions: </source>
        <translation>Hata: izinler işlenmeye çalışılıyor:</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="58"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="about.cpp" line="59"/>
        <location filename="about.cpp" line="69"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="about.cpp" line="60"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="about.cpp" line="81"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="main.cpp" line="61"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
